:orphan:

Getting started
===============

Welcome to Isso's documentation. This documentation will help you get started
fast. If you run into any problems when using Isso, you can find the answer in
`troubleshooting guide <guides/troubleshooting>`_ or you can
:ref:`get in contact <contact>`

**Start here:**

1. :doc:`Install Isso <reference/installation>`
2. :doc:`Follow the Quickstart guide <guides/quickstart>`
3. If you get in stuck, see :doc:`Troubleshooting <guides/troubleshooting>`

Once you're familiar with Isso, check out the sidebar and the search on the
left to find further information.

.. note::
   Contributions to the documentation and to the project as a whole are
   welcome! See :doc:`/docs/contributing/index` and
   :doc:`/docs/contributing/documentation` for more details.

What's Isso?
------------

Isso is a lightweight commenting server similar to Disqus. It allows anonymous
comments, maintains identity and is simple to administrate. It uses JavaScript
and cross-origin ressource sharing for easy integration into (static) websites.

What's wrong with Disqus?
-------------------------

No anonymous comments (IP address, email and name recorded), hosted in the USA,
third-party. Just like IntenseDebate etc. When you embed Disqus, they
can do anything with your readers (and probably mine Bitcoins, see the loading
times).
